@@ -21,6 +21,7 @@ describe 'magnum::keystone::authtoken' do
         :project_name                   => 'services',
         :user_domain_name               => 'Default',
         :project_domain_name            => 'Default',
+        :system_scope                   => '<SERVICE DEFAULT>',
         :insecure                       => '<SERVICE DEFAULT>',
         :auth_section                   => '<SERVICE DEFAULT>',
         :auth_type                      => 'password',
@@ -70,6 +71,7 @@ describe 'magnum::keystone::authtoken' do
           :project_name                   => 'service_project',
           :user_domain_name               => 'domainX',
           :project_domain_name            => 'domainX',
+          :system_scope                   => 'all',
           :insecure                       => false,
           :auth_section                   => 'new_section',
           :auth_type                      => 'password',
@@ -110,6 +112,7 @@ describe 'magnum::keystone::authtoken' do
         :project_name                   => params[:project_name],
         :user_domain_name               => params[:user_domain_name],
         :project_domain_name            => params[:project_domain_name],
+        :system_scope                   => params[:system_scope],
         :insecure                       => params[:insecure],
         :auth_section                   => params[:auth_section],
         :auth_type                      => params[:auth_type],
